@@ -108,6 +108,11 @@ def main():
         default=default_args.pop("key_of_interest", None),
         help="log key of interest",
     )
+    parser.add_argument(
+        "--no-epoch",
+        default=default_args.pop("no_epoch", False),
+        help="no epoch (e.g., reinforcement learning)",
+    )
     args = parser.parse_args()
 
     if args.version:
@@ -133,6 +138,7 @@ def main():
         key_iteration=args.key_iteration,
         key_elapsed_time=args.key_elapsed_time,
         key_of_interest=args.key_of_interest,
+        no_epoch=args.no_epoch,
     )
 
     if args.index is not None:
@@ -173,8 +179,7 @@ def main():
                 for key_split in key_splits
                 for x in textwrap.wrap(key_split, width=args.column)
             ]
-        key = "\n".join(key_splits)
-        headers.append(key)
+        headers.append("\n".join(key_splits))
         if args.multi_column and key in log_keys:
             headers.append("")
 
